@@ -17,7 +17,7 @@ from django.contrib.contenttypes.models import ContentType
 from django.contrib.sites.models import Site, get_current_site
 from django.core.exceptions import PermissionDenied, ObjectDoesNotExist, ValidationError
 from django.core.urlresolvers import reverse
-from django.db import router, transaction
+from django.db import router
 from django.http import HttpResponseRedirect, HttpResponse, Http404, HttpResponseBadRequest, HttpResponseForbidden
 from django.shortcuts import render_to_response, get_object_or_404
 from django.template.context import RequestContext
@@ -29,9 +29,10 @@ from django.views.decorators.http import require_POST
 from cms.admin.placeholderadmin import PlaceholderAdminMixin
 from cms.plugin_pool import plugin_pool
 from cms.utils.conf import get_cms_setting
-from cms.utils.compat.dj import force_unicode
+from cms.utils.compat.dj import force_unicode, is_installed
 from cms.utils.compat.urls import unquote
 from cms.utils.helpers import find_placeholder_relation
+from cms.utils.urlutils import add_url_parameters
 from cms.admin.change_list import CMSChangeList
 from cms.admin.dialog.views import get_copy_dialog
 from cms.admin.forms import (PageForm, AdvancedSettingsForm, PagePermissionForm,
@@ -46,10 +47,11 @@ from cms.utils.admin import jsonify_request
 from cms.utils.permissions import has_global_page_permission, has_generic_permission
 from cms.utils.plugins import current_site
 from cms.utils.compat import DJANGO_1_4
+from cms.utils.transaction import wrap_transaction
 
 require_POST = method_decorator(require_POST)
 
-if 'reversion' in settings.INSTALLED_APPS:
+if is_installed('reversion'):
     from reversion.admin import VersionAdmin as ModelAdmin
     from reversion import create_revision
 else:  # pragma: no cover
@@ -246,68 +248,72 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
         else:
             return form.fieldsets
 
+    def get_inline_classes(self, request, obj=None, **kwargs):
+        if obj and 'permission' in request.path:
+            return PERMISSION_ADMIN_INLINES
+        return []
+
+    def get_form_class(self, request, obj=None, **kwargs):
+        if 'advanced' in request.path:
+            return AdvancedSettingsForm
+        elif 'permission' in request.path:
+            return PagePermissionForm
+        elif 'dates' in request.path:
+            return PublicationDatesForm
+        return self.form
+
     def get_form(self, request, obj=None, **kwargs):
         """
         Get PageForm for the Page model and modify its fields depending on
         the request.
         """
         language = get_language_from_request(request, obj)
-        if "advanced" in request.path:
-            form = super(PageAdmin, self).get_form(request, obj, form=AdvancedSettingsForm, **kwargs)
-        elif "permission" in request.path:
-            form = super(PageAdmin, self).get_form(request, obj, form=PagePermissionForm, **kwargs)
-        elif "dates" in request.path:
-            form = super(PageAdmin, self).get_form(request, obj, form=PublicationDatesForm, **kwargs)
-        else:
-            form = super(PageAdmin, self).get_form(request, obj, form=PageForm, **kwargs)
+        form_cls = self.get_form_class(request, obj)
+        form = super(PageAdmin, self).get_form(request, obj, form=form_cls, **kwargs)
+
         if 'language' in form.base_fields:
             form.base_fields['language'].initial = language
+
         if 'page_type' in form.base_fields:
             if 'copy_target' in request.GET or 'add_page_type' in request.GET or obj:
                 del form.base_fields['page_type']
-            elif not Title.objects.filter(page__parent__reverse_id=PAGE_TYPES_ID, language=language).count():
+            elif not Title.objects.filter(page__parent__reverse_id=PAGE_TYPES_ID, language=language).exists():
                 del form.base_fields['page_type']
+
         if 'add_page_type' in request.GET:
             del form.base_fields['menu_title']
             del form.base_fields['meta_description']
             del form.base_fields['page_title']
-        if obj:
-            if "permission" in request.path:
-                self.inlines = PERMISSION_ADMIN_INLINES
-            else:
-                self.inlines = []
-            version_id = None
-            if "history" in request.path or 'recover' in request.path:
-                version_id = request.path.split("/")[-2]
 
-            title_obj = obj.get_title_obj(language=language, fallback=False, version_id=version_id,
-                                          force_reload=True)
+        self.inlines = self.get_inline_classes(request, obj, **kwargs)
+
+        if obj:
+            if 'history' in request.path or 'recover' in request.path:
+                version_id = request.path.split('/')[-2]
+            else:
+                version_id = None
+
+            title_obj = obj.get_title_obj(language=language, fallback=False, version_id=version_id, force_reload=True)
+
             if 'site' in form.base_fields and form.base_fields['site'].initial is None:
                 form.base_fields['site'].initial = obj.site
-            for name in [
-                'slug',
-                'title',
-                'meta_description',
-                'menu_title',
-                'page_title',
-                'redirect',
-            ]:
+
+            for name in ('slug', 'title', 'meta_description', 'menu_title', 'page_title', 'redirect'):
                 if name in form.base_fields:
                     form.base_fields[name].initial = getattr(title_obj, name)
+
             if 'overwrite_url' in form.base_fields:
                 if title_obj.has_url_overwrite:
                     form.base_fields['overwrite_url'].initial = title_obj.path
                 else:
-                    form.base_fields['overwrite_url'].initial = ""
+                    form.base_fields['overwrite_url'].initial = ''
+
         else:
-            self.inlines = []
-            for name in ['slug', 'title']:
+            for name in ('slug', 'title'):
                 form.base_fields[name].initial = u''
+
             if 'target' in request.GET or 'copy_target' in request.GET:
-                if 'target' in request.GET:
-                    target = request.GET['target']
-                if 'copy_target' in request.GET:
-                    target = request.GET['copy_target']
+                target = request.GET.get('copy_target') or request.GET.get('target')
                 if 'position' in request.GET:
                     position = request.GET['position']
                     if position == 'last-child' or position == 'first-child':
@@ -317,7 +323,9 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
                         form.base_fields['parent'].initial = sibling.parent_id
                 else:
                     form.base_fields['parent'].initial = request.GET.get('target', None)
+
             form.base_fields['site'].initial = request.session.get('cms_admin_site', None)
+
         return form
 
     def advanced(self, request, object_id):
@@ -512,7 +520,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
         """
         Returns True if the use has the right to recover pages
         """
-        if not "reversion" in settings.INSTALLED_APPS:
+        if not is_installed('reversion'):
             return False
         user = request.user
         if user.is_superuser:
@@ -589,7 +597,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
         return True
 
     def post_add_plugin(self, request, placeholder, plugin):
-        if 'reversion' in settings.INSTALLED_APPS and placeholder.page:
+        if is_installed('reversion') and placeholder.page:
             plugin_name = force_unicode(plugin_pool.get_plugin(plugin.plugin_type).name)
             message = _(u"%(plugin_name)s plugin added to %(placeholder)s") % {
                 'plugin_name': plugin_name, 'placeholder': placeholder}
@@ -598,7 +606,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
 
     def post_copy_plugins(self, request, source_placeholder, target_placeholder, plugins):
         page = target_placeholder.page
-        if page and "reversion" in settings.INSTALLED_APPS:
+        if page and is_installed('reversion'):
             message = _(u"Copied plugins to %(placeholder)s") % {'placeholder': target_placeholder}
             self.cleanup_history(page)
             helpers.make_revision_with_plugins(page, request.user, message)
@@ -607,7 +615,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
         page = plugin.placeholder.page
         if page:
             # if reversion is installed, save version of the page plugins
-            if 'reversion' in settings.INSTALLED_APPS and page:
+            if is_installed('reversion') and page:
                 plugin_name = force_unicode(plugin_pool.get_plugin(plugin.plugin_type).name)
                 message = _(
                     u"%(plugin_name)s plugin edited at position %(position)s in %(placeholder)s") % {
@@ -620,7 +628,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
 
     def post_move_plugin(self, request, source_placeholder, target_placeholder, plugin):
         page = target_placeholder.page
-        if page and 'reversion' in settings.INSTALLED_APPS:
+        if page and is_installed('reversion'):
             self.cleanup_history(page)
             helpers.make_revision_with_plugins(page, request.user, _(u"Plugins were moved"))
 
@@ -634,7 +642,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
                 'position': plugin.position,
                 'placeholder': plugin.placeholder,
             }
-            if 'reversion' in settings.INSTALLED_APPS:
+            if is_installed('reversion'):
                 self.cleanup_history(page)
                 helpers.make_revision_with_plugins(page, request.user, comment)
 
@@ -645,7 +653,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
             comment = _('All plugins in the placeholder "%(name)s" were deleted.') % {
                 'name': force_unicode(placeholder)
             }
-            if 'reversion' in settings.INSTALLED_APPS:
+            if is_installed('reversion'):
                 self.cleanup_history(page)
                 helpers.make_revision_with_plugins(page, request.user, comment)
 
@@ -712,7 +720,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
             'site_languages': languages,
             'open_menu_trees': open_menu_trees,
         }
-        if 'reversion' in settings.INSTALLED_APPS:
+        if is_installed('reversion'):
             context['has_recover_permission'] = self.has_recover_permission(request)
             context['has_change_permission'] = self.has_change_permission(request)
         context.update(extra_context or {})
@@ -765,7 +773,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
 
     @require_POST
     def undo(self, request, object_id):
-        if not 'reversion' in settings.INSTALLED_APPS:
+        if not is_installed('reversion'):
             return HttpResponseBadRequest('django reversion not installed')
         from reversion.models import Revision
         from cms.utils.page_resolver import is_valid_url
@@ -832,7 +840,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
 
     @require_POST
     def redo(self, request, object_id):
-        if not 'reversion' in settings.INSTALLED_APPS:
+        if not is_installed('reversion'):
             return HttpResponseBadRequest('django reversion not installed')
         from reversion.models import Revision
         import reversion
@@ -909,13 +917,13 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
 
         page.template = to_template
         page.save()
-        if "reversion" in settings.INSTALLED_APPS:
+        if is_installed('reversion'):
             message = _("Template changed to %s") % dict(get_cms_setting('TEMPLATES'))[to_template]
             self.cleanup_history(page)
             helpers.make_revision_with_plugins(page, request.user, message)
         return HttpResponse(force_unicode(_("The template was successfully changed")))
 
-    @transaction.commit_on_success
+    @wrap_transaction
     def move_page(self, request, page_id, extra_context=None):
         """
         Move the page to the requested target, at the given position
@@ -938,7 +946,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
                 HttpResponseForbidden(force_unicode(_("Error! You don't have permissions to move this page. Please reload the page"))))
             # move page
         page.move_page(target, position)
-        if "reversion" in settings.INSTALLED_APPS:
+        if is_installed('reversion'):
             self.cleanup_history(page)
             helpers.make_revision_with_plugins(page, request.user, _("Page moved"))
 
@@ -977,7 +985,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
         return render_to_response('admin/cms/page/permissions.html', context)
 
     @require_POST
-    @transaction.commit_on_success
+    @wrap_transaction
     def copy_language(self, request, page_id):
         with create_revision():
             source_language = request.POST.get('source_language')
@@ -993,15 +1001,14 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
                 if not self.has_copy_plugin_permission(request, placeholder, placeholder, plugins):
                     return HttpResponseForbidden(force_unicode(_('You do not have permission to copy these plugins.')))
                 copy_plugins.copy_plugins_to(plugins, placeholder, target_language)
-            if page and "reversion" in settings.INSTALLED_APPS:
+            if page and is_installed('reversion'):
                 message = _(u"Copied plugins from %(source_language)s to %(target_language)s") % {
                     'source_language': source_language, 'target_language': target_language}
                 self.cleanup_history(page)
                 helpers.make_revision_with_plugins(page, request.user, message)
             return HttpResponse("ok")
 
-
-    @transaction.commit_on_success
+    @wrap_transaction
     def copy_page(self, request, page_id, extra_context=None):
         """
         Copy the page and all its plugins and descendants to the requested target, at the given position
@@ -1034,7 +1041,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
         context.update(extra_context or {})
         return HttpResponseRedirect('../../')
 
-    @transaction.commit_on_success
+    @wrap_transaction
     @create_revision()
     def publish_page(self, request, page_id, language):
         try:
@@ -1077,7 +1084,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
                     messages.warning(request, _("Page not published! A parent page is not published yet."))
                 else:
                     messages.warning(request, _("There was a problem publishing your content"))
-        if "reversion" in settings.INSTALLED_APPS and page:
+        if is_installed('reversion') and page:
             self.cleanup_history(page, publish=True)
             helpers.make_revision_with_plugins(page, request.user, PUBLISH_COMMENT)
             # create a new publish reversion
@@ -1108,7 +1115,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
         return HttpResponseRedirect(path)
 
     def cleanup_history(self, page, publish=False):
-        if "reversion" in settings.INSTALLED_APPS and page:
+        if is_installed('reversion') and page:
             # delete revisions that are not publish revisions
             from reversion.models import Version
 
@@ -1134,8 +1141,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
                         revision.delete()
                         deleted.append(revision.pk)
 
-
-    @transaction.commit_on_success
+    @wrap_transaction
     def unpublish(self, request, page_id, language):
         """
         Publish or unpublish a language of a page
@@ -1170,7 +1176,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
             path = "%s?language=%s&page_id=%s" % (path, request.GET.get('redirect_language'), request.GET.get('redirect_page_id'))
         return HttpResponseRedirect(path)
 
-    @transaction.commit_on_success
+    @wrap_transaction
     def revert_page(self, request, page_id, language):
         page = get_object_or_404(Page, id=page_id)
         # ensure user has permissions to publish this page
@@ -1193,8 +1199,10 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
 
     @create_revision()
     def delete_translation(self, request, object_id, extra_context=None):
-
-        language = get_language_from_request(request)
+        if 'language' in request.GET:
+            language = request.GET['language']
+        else:
+            language = get_language_from_request(request)
 
         opts = Page._meta
         titleopts = Title._meta
@@ -1263,7 +1271,7 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
             if public:
                 public.save()
 
-            if "reversion" in settings.INSTALLED_APPS:
+            if is_installed('reversion'):
                 self.cleanup_history(obj)
                 helpers.make_revision_with_plugins(obj, request.user, message)
 
@@ -1327,22 +1335,18 @@ class PageAdmin(PlaceholderAdminMixin, ModelAdmin):
 
     def add_page_type(self, request):
         site = Site.objects.get_current()
-        language = request.GET.get('language')
+        language = request.GET.get('language') or get_language()
         target = request.GET.get('copy_target')
-        try:
-            type_root = Page.objects.get(reverse_id=PAGE_TYPES_ID, publisher_is_draft=True, site_id=site.pk)
-        except Page.DoesNotExist:
-            type_root = Page(reverse_id=PAGE_TYPES_ID, site=site, in_navigation=False)
-            type_root.save()
-            language = get_language()
-            type_title = Title(title=_("Page Types"), language=language, slug=PAGE_TYPES_ID, page=type_root)
-            type_title.save()
-        return HttpResponseRedirect("%s?target=%s&position=first-child&add_page_type=1&copy_target=%s&language=%s" % (
-            reverse("admin:cms_page_add"),
-            type_root.pk,
-            target,
-            language
-        ))
+
+        type_root, created = Page.objects.get_or_create(reverse_id=PAGE_TYPES_ID, publisher_is_draft=True, site=site,
+                                                        defaults={'in_navigation': False})
+        type_title, created = Title.objects.get_or_create(page=type_root, language=language, slug=PAGE_TYPES_ID,
+                                                          defaults={'title': _('Page Types')})
+
+        url = add_url_parameters(reverse('admin:cms_page_add'), target=type_root.pk, position='first-child',
+                                 add_page_type=1, copy_target=target, language=language)
+
+        return HttpResponseRedirect(url)
 
     def resolve(self, request):
         if not request.user.is_staff:
