@@ -2,6 +2,7 @@
 """
 Edit Toolbar middleware
 """
+from cms.utils.conf import get_cms_setting
 from cms.toolbar.toolbar import CMSToolbar
 from cms.utils.i18n import force_language
 from django.contrib.admin.models import LogEntry, ADDITION, CHANGE
@@ -52,19 +53,24 @@ class ToolbarMiddleware(object):
         If we should show the toolbar for this request, put it on
         request.toolbar. Then call the request_hook on the toolbar.
         """
-        if 'edit' in request.GET and not request.session.get('cms_edit', False):
+
+        edit_on = get_cms_setting('CMS_TOOLBAR_URL__EDIT_ON')
+        edit_off = get_cms_setting('CMS_TOOLBAR_URL__EDIT_OFF')
+        build = get_cms_setting('CMS_TOOLBAR_URL__BUILD')
+
+        if edit_on in request.GET and not request.session.get('cms_edit', False):
             if not request.session.get('cms_edit', False):
                 menu_pool.clear()
             request.session['cms_edit'] = True
             if request.session.get('cms_build', False):
                 request.session['cms_build'] = False
-        if 'edit_off' in request.GET and request.session.get('cms_edit', True):
+        if edit_off in request.GET and request.session.get('cms_edit', True):
             if request.session.get('cms_edit', True):
                 menu_pool.clear()
             request.session['cms_edit'] = False
             if request.session.get('cms_build', False):
                 request.session['cms_build'] = False
-        if 'build' in request.GET and not request.session.get('cms_build', False):
+        if build in request.GET and not request.session.get('cms_build', False):
             request.session['cms_build'] = True
         if request.user.is_staff:
             try:
@@ -99,9 +105,13 @@ class ToolbarMiddleware(object):
                     user=request.user,
                     action_flag__in=(ADDITION, CHANGE)
                 ).only('pk').order_by('-pk')[0].pk
+                if hasattr(request, 'cms_latest_entry') and request.cms_latest_entry != pk:
+                    log = LogEntry.objects.filter(user=request.user, action_flag__in=(ADDITION, CHANGE))[0]
+                    request.session['cms_log_latest'] = log.pk
+            # If there were no LogEntries, just don't touch the session.
+            # Note that in the case of a user logging-in as another user,
+            # request may have a cms_latest_entry attribute, but there are no
+            # LogEntries for request.user.
             except IndexError:
-                pk = -1
-            if hasattr(request, 'cms_latest_entry') and request.cms_latest_entry != pk:
-                log = LogEntry.objects.filter(user=request.user, action_flag__in=(ADDITION, CHANGE))[0]
-                request.session['cms_log_latest'] = log.pk
+                pass
         return response
