@@ -1,9 +1,9 @@
-from django.conf.urls.defaults import *
+from django.conf.urls import patterns, url
 
 """
 Also used in cms.tests.ApphooksTestCase
 """
 
 urlpatterns = patterns('cms.test_utils.project.sampleapp.views',
-    url(r'^current-app/$', 'current_app', name='current-app'),
+    url(r'^current-app/$', 'current_app', name='current-app' ),
 )
