@@ -1,15 +1,17 @@
 # -*- coding: utf-8 -*-
 from contextlib import contextmanager
+from shutil import rmtree as _rmtree
+from tempfile import template, mkdtemp
+import sys
+
 from django.conf import settings
 from django.core.signals import request_started
 from django.db import reset_queries
 from django.template import context
 from django.utils.translation import get_language, activate
-from shutil import rmtree as _rmtree
-from tempfile import template, mkdtemp
-import sys
+
 from cms.utils.compat.string_io import StringIO
-from cms.compat import get_user_model
+from cms.utils.compat.dj import get_user_model
 
 
 class NULL:
