@@ -1,20 +1,29 @@
+from django.http import HttpResponse
+
 from cms.test_utils.testcases import CMSTestCase
 from cms.test_utils.util.mock import AttributeObject
-from django.http import HttpResponse
 from menus.templatetags.menu_tags import PageLanguageUrl
-from menus.utils import (simple_language_changer, find_selected, 
-    language_changer_decorator)
+from menus.utils import (simple_language_changer, find_selected,
+                         language_changer_decorator)
 
 
 class DumbPageLanguageUrl(PageLanguageUrl):
     def __init__(self): pass
 
+
 class MenuUtilsTests(CMSTestCase):
     def get_simple_view(self):
         def myview(request):
             return HttpResponse('')
         return myview
-    
+
+    def test_reverse_in_changer(self):
+        response = self.client.get('/en/sample/login/')
+        self.assertContains(response, '<h1>/fr/sample/login/</h1>')
+
+        response = self.client.get('/en/sample/login_other/')
+        self.assertContains(response, '<h1>/fr/sample/login_other/</h1>')
+
     def test_simple_language_changer(self):
         func = self.get_simple_view()
         decorated_view = simple_language_changer(func)
@@ -22,7 +31,7 @@ class MenuUtilsTests(CMSTestCase):
         self.assertEqual(func.__name__, decorated_view.__name__)
         request = self.get_request('/', 'en')
         response = decorated_view(request)
-        self.assertEqual(response.content, '')
+        self.assertEqual(response.content, b'')
         fake_context = {'request': request}
         tag = DumbPageLanguageUrl()
         output = tag.get_context(fake_context, 'en')
@@ -38,7 +47,7 @@ class MenuUtilsTests(CMSTestCase):
         self.assertEqual(view.__name__, view.__name__)
         request = self.get_request('/en/', 'en')
         response = view(request)
-        self.assertEqual(response.content, '')
+        self.assertEqual(response.content, b'')
         fake_context = {'request': request}
         tag = DumbPageLanguageUrl()
         output = tag.get_context(fake_context, 'en')
@@ -54,7 +63,7 @@ class MenuUtilsTests(CMSTestCase):
         decorated_view = language_changer_decorator(lang_changer)(self.get_simple_view())
         request = self.get_request('/some/path/', 'en')
         response = decorated_view(request)
-        self.assertEqual(response.content, '')
+        self.assertEqual(response.content, b'')
         fake_context = {'request': request}
         tag = DumbPageLanguageUrl()
         output = tag.get_context(fake_context, 'en')
@@ -63,8 +72,7 @@ class MenuUtilsTests(CMSTestCase):
         output = tag.get_context(fake_context, 'ja')
         url = output['content']
         self.assertEqual(url, '/ja/dummy/')
-        
-        
+
     def test_find_selected(self):
         subchild = AttributeObject()
         firstchild = AttributeObject(ancestor=True, children=[subchild])
