@@ -2,6 +2,9 @@ from unittest import TestCase
 from cms.test_utils.util.static_analysis import pyflakes
 
 
-class StaticAnalysisTest(TestCase):
+class AboveStaticAnalysisCodeTest(TestCase):
+    """
+    Name is pretty lame, but ensure it's executed before every other test
+    """
     def test_pyflakes(self):
         self.assertEqual(pyflakes(), 0)
